==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/contextInformation/Lyrics.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.contextInformation;

import java.beans.ConstructorProperties;
import net.sourceforge.atunes.utils.StringUtils;

public class Lyrics {

	private String lyrics;
	private String url;

	@ConstructorProperties( { "lyrics", "url" })
	public Lyrics(String lyrics, String url) {
		setLyrics(lyrics);
		this.url = url;
	}

	public void setLyrics(String lyrics) {
		if (lyrics == null) {
			throw new IllegalArgumentException();
		}
		// Many lyrics contain html escape sequences so unescape
		lyrics = StringUtils.unescapeHTML(lyrics, 0);
		this.lyrics = lyrics;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getLyrics() {
		return lyrics;
	}

	public String getUrl() {
		return url;
	}

}

==> aTunes_1.11.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/contextInformation/Lyrics.java <==
/*
 * aTunes 1.11.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.contextInformation;

import java.beans.ConstructorProperties;
import net.sourceforge.atunes.utils.StringUtils;

public class Lyrics {

	private String lyrics;
	private String url;

	@ConstructorProperties( { "lyrics", "url" })
	public Lyrics(String lyrics, String url) {
		setLyrics(lyrics);
		this.url = url;
	}

	public void setLyrics(String lyrics) {
		if (lyrics == null) {
			throw new IllegalArgumentException();
		}
		// Many lyrics contain html escape sequences so unescape
		lyrics = StringUtils.unescapeHTML(lyrics, 0);
		this.lyrics = lyrics != null ? lyrics : "";
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getLyrics() {
		return lyrics;
	}

	public String getUrl() {
		return url;
	}

}
